@@ -8,9 +8,8 @@ Re-implementation of `Higlass gene-annotations track`_
 """
 # category: composite visualizations
 import gosling as gos
-from gosling.data import beddb
 
-genes = beddb(
+genes = gos.beddb(
     url="https://server.gosling-lang.org/api/v1/tileset_info/?d=gene-annotation",
     genomicFields=[
       {"index": 1, "name": "start"},
@@ -27,20 +26,15 @@ genes = beddb(
 )
 
 base = gos.Track(genes).encode(
-    row=gos.Channel("strand:N", domain=["+", "-"]),
-    color=gos.Channel("strand:N", domain=["+", "-"], range=["#7585FF", "#FF8A85"]),
-    tooltip=[
-        gos.Tooltip(field="start", type="genomic", alt="Start Position"),
-        gos.Tooltip(field="end", type="genomic", alt="End Position"),
-        gos.Tooltip(field="strand", type="nominal", alt="Strand"),
-        gos.Tooltip(field="name", type="nominal", alt="Name")
-    ]
+    row=gos.Row("strand:N", domain=["+", "-"]),
+    color=gos.Color("strand:N", domain=["+", "-"], range=["#7585FF", "#FF8A85"]),
+    tooltip=["start:G", "end:G", "strand:N", "name:N"],
 ).properties(
     title="Genes | hg38",
 )
 
 plusGeneHead = base.mark_triangleRight(align="left").encode(
-    x=gos.Channel("end:G", axis="top"),
+    x=gos.X("end:G", axis="top"),
     size=gos.value(15)
 ).transform_filter(
     field="type", oneOf=["gene"]
@@ -49,7 +43,7 @@ plusGeneHead = base.mark_triangleRight(align="left").encode(
 )
 
 minusGeneHead = base.mark_triangleLeft(align="right").encode(
-    x=gos.Channel("start:G", axis="top"),
+    x=gos.X("start:G", axis="top"),
     size=gos.value(15)
 ).transform_filter(
     field="type", oneOf=["gene"]
@@ -58,9 +52,9 @@ minusGeneHead = base.mark_triangleLeft(align="right").encode(
 )
 
 geneLabel = base.mark_text(dy=15).encode(
-    x=gos.Channel("start:G", axis="top"),
-    xe=gos.Channel("end:G"),
-    text=gos.Channel("name:N"),
+    x=gos.X("start:G", axis="top"),
+    xe="end:G",
+    text="name:N",
     size=gos.value(15)
 ).transform_filter(
     field="type", oneOf=["gene"]
@@ -72,16 +66,16 @@ geneLabel = base.mark_text(dy=15).encode(
 )
 
 exon = base.mark_rect().encode(
-    x=gos.Channel("start:G", axis="top"),
-    xe=gos.Channel("end:G"),
+    x=gos.X("start:G", axis="top"),
+    xe="end:G",
     size=gos.value(15)
 ).transform_filter(
     field="type", oneOf=["exon"]
 )
 
 plusGeneRange = base.mark_rule(linePattern={"type": "triangleRight", "size": 5}).encode(
-    x=gos.Channel("start:G", axis="top"),
-    xe=gos.Channel("end:G"),
+    x=gos.X("start:G", axis="top"),
+    xe="end:G",
     strokeWidth=gos.value(3),
 ).transform_filter(
     field="type", oneOf=["gene"]
@@ -90,8 +84,8 @@ plusGeneRange = base.mark_rule(linePattern={"type": "triangleRight", "size": 5})
 )
 
 minusGeneRange = base.mark_rule(linePattern={"type": "triangleLeft", "size": 5}).encode(
-    x=gos.Channel("start:G", axis="top"),
-    xe=gos.Channel("end:G"),
+    x=gos.X("start:G", axis="top"),
+    xe="end:G",
     strokeWidth=gos.value(3),
 ).transform_filter(
     field="type", oneOf=["gene"]
@@ -104,7 +98,7 @@ gos.overlay(
 ).properties(
     width=725, height=100,
     title="Gene Annotation",
-    xDomain=gos.Domain(chromosome="1", interval=[103400000, 103700000]),
+    xDomain=gos.GenomicDomain(chromosome="1", interval=[103400000, 103700000]),
     assembly="hg38",
     layout="linear",
     centerRadius=0.7,
