@@ -4,9 +4,8 @@ Multiscale Lollipop Plot
 """
 # category: interactive visualizations
 import gosling as gos
-from gosling.data import beddb, multivec
  
-clin_var_beddb = beddb(
+clin_var_beddb = gos.beddb(
     url="https://server.gosling-lang.org/api/v1/tileset_info/?d=clinvar-beddb",
     genomicFields=[{"index": 1, "name": "start"}, {"index": 2, "name": "end"}],
     valueFields=[{"index": 7, "name": "significance", "type": "nominal"}],
@@ -20,7 +19,7 @@ categories = [
 
 colors = ["#5A9F8C", "#5A9F8C", "#029F73", "gray", "#CB96B3", "#CB71A3", "#CB3B8C"]
 
-clin_var_multivec = multivec(
+clin_var_multivec = gos.multivec(
     url="https://server.gosling-lang.org/api/v1/tileset_info/?d=clinvar-multivec",
     row="significance",
     column="position",
@@ -34,7 +33,7 @@ lolipop = gos.overlay(
     (
         gos.Track(clin_var_beddb).mark_bar().encode(
             x="start:G",
-            y=gos.Channel("significance:N", domain=categories, range=[150, 20], baseline="Uncertain_significance"),
+            y=gos.Y("significance:N", domain=categories, range=[150, 20], baseline="Uncertain_significance"),
             size=gos.value(1),
             color=gos.value("lightgray"),
             stroke=gos.value("lightgray"),
@@ -50,8 +49,8 @@ lolipop = gos.overlay(
     (
         gos.Track(clin_var_beddb).mark_point().encode(
             x="start:G",
-            color=gos.Channel("significance:N", domain=categories, range=colors),
-            row=gos.Channel("significance:N", domain=categories),
+            color=gos.Color("significance:N", domain=categories, range=colors),
+            row=gos.Row("significance:N", domain=categories),
             size=gos.value(7),
             opacity=gos.value(0.8),
         ).visibility_lt(
@@ -65,8 +64,8 @@ lolipop = gos.overlay(
         gos.Track(clin_var_multivec).mark_bar().encode(
             x="start:G",
             xe="end:G",
-            y=gos.Channel("count:Q", axis="none"),
-            color=gos.Channel("significance:N", domain=categories, range=colors, legend=True)
+            y=gos.Y("count:Q", axis="none"),
+            color=gos.Color("significance:N", domain=categories, range=colors, legend=True)
         ).visibility_gt(
             measure="zoomLevel",
             target="mark",
@@ -76,6 +75,7 @@ lolipop = gos.overlay(
     ),
     width=725,
     height=150,
+    xDomain=gos.GenomicDomain(chromosome="13", interval=[31500000, 33150000]),
 )
 
 lolipop
