@@ -4,9 +4,8 @@ Point Plot
 """
 # category: basic marks
 import gosling as gos
-from gosling.data import multivec
 
-data = multivec(
+data = gos.multivec(
     url="https://resgen.io/api/v1/tileset_info/?d=UvVPeLHuRDiYA3qwFlm7xQ",
     row="sample",
     column="position",
@@ -15,10 +14,10 @@ data = multivec(
     binSize=5,
 )
 
-domain = gos.Domain(chromosome="1", interval=[1, 30005000])
+domain = gos.GenomicDomain(chromosome="1", interval=[1, 30005000])
 
 track = gos.Track(data).mark_point().encode(
-    x=gos.Channel("position:G", domain=domain, axis="bottom"),
+    x=gos.X("position:G", domain=domain, axis="bottom"),
     y="peak:Q",
     size="peak:Q",
     color="sample:N",
