@@ -4,9 +4,8 @@ Text Marks
 """
 # category: basic marks
 import gosling as gos
-from gosling.data import multivec
 
-data = multivec(
+data = gos.multivec(
     url="https://resgen.io/api/v1/tileset_info/?d=UvVPeLHuRDiYA3qwFlm7xQ",
     row="base",
     column="position",
@@ -19,9 +18,9 @@ data = multivec(
 
 track = gos.Track(data).mark_text(textStrokeWidth=0).encode(
     y="count:Q",
-    x=gos.Channel("start:G", axis="top"),
+    x=gos.X("start:G", axis="top"),
     xe="end:G",
-    color=gos.Channel("base:N", domain=["A", "T", "G", "C"]),
+    color=gos.Color("base:N", domain=["A", "T", "G", "C"]),
     text="base:N",
 ).properties(width=725, height=180, stretch=True)
 
